MainSection class

Constructors

MainSection({required Widget itemBuilder(BuildContext context, int index, bool selected), required int itemCount, required DetailsWidget getDetails(BuildContext context, int index), required Icon icon, required Text label, Widget? bottomAppBar})
const

Properties

bottomAppBar → Widget?
final
getDetails → DetailsWidget Function(BuildContext context, int index)
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Icon
final
itemBuilder → Widget Function(BuildContext context, int index, bool selected)
final
itemCount → int
final
label → Text
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited