MobileView class

Inheritance

Constructors

MobileView({Key? key, required List<Widget>? slivers, required DetailWidgetBuilder detailBuilder, required List<Widget> children, required Key? detailScaffoldKey, required bool useRootNavigator, required NavigatorState? navigator, required Widget? nullItems, required Widget? emptyItems})
MobileView.builder({Key? key, required List<Widget>? slivers, required DetailWidgetBuilder detailBuilder, required int itemCount, required IndexedWidgetBuilder itemBuilder, required Key? detailScaffoldKey, required bool useRootNavigator, required NavigatorState? navigator, required Widget? nullItems, required Widget? emptyItems})
MobileView.custom({Key? key, required List<Widget>? slivers, required DetailWidgetBuilder detailBuilder, required SliverChildDelegate childDelagate, required Key? detailScaffoldKey, required bool useRootNavigator, required NavigatorState? navigator, required Widget? nullItems, required Widget? emptyItems})
const

Properties

childDelagate → SliverChildDelegate
final
detailBuilder → DetailWidgetBuilder
final
detailScaffoldKey → Key?
final
emptyItems → Widget?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
final
nullItems → Widget?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slivers → List<Widget>?
final
useRootNavigator → bool
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited